// IIFE para evitar conflictos en el ámbito global
(function() {
    let diccionario = {};
    const mensajesContainer = document.getElementById('mensajes');
    const entradaMensaje = document.getElementById('texto-mensaje');
    let historialRespuestas = []; // Historial global de respuestas únicas

    // Lista de rutas de archivos JSON que se cargarán
    const rutasJSON = [
        './json/conocenos.json',
        './json/saludos.json',
        './json/menu.json',
        './json/historia.json',
        './json/equipo.json',
        './json/contacto.json',
        './json/info.json',
        './json/horarios.json',
        './json/metodos_pago.json',
        './json/facturacion.json',
        './json/garantias.json',
        './json/entregas.json',
        './json/politicas.json',
        './json/valores-corporativos.json',
        './json/citas.json',
        './json/despedidas.json',
        './json/chatbot.json',
        './json/musica.json',
        './json/ofertas.json',
        './json/opiniones.json',
        './json/planes_especiales.json',
        './json/pqrs.json',
        './json/precios.json',
        './json/productos.json',
        './json/productos_recomendados.json',
        './json/reservaciones.json',
        './json/servicios.json',
        './json/soporte.json',
        './json/ubicaciones.json',
        './json/video.json',
        './json/secretos.json',
        './json/cafe.json'
        ];




async function cargarIntencionesDinamicamente() {
    try {
        // Cargar archivos prioritarios primero
        const prioritarios = ['./saludos.json'];
        for (const ruta of prioritarios) {
            const respuestaArchivo = await fetch(ruta);
            const datos = await respuestaArchivo.json();
            const nombreContexto = ruta.split('/').pop().replace('.json', '');
            diccionario[nombreContexto] = datos;
            historialRespuestas[nombreContexto] = [];
            console.log(`Cargado prioritario: ${nombreContexto}`);
        }

        // Cargar los demás archivos en paralelo
        const promesas = rutasJSON
            .filter(ruta => !prioritarios.includes(ruta))
            .map(async (ruta) => {
                const respuestaArchivo = await fetch(ruta);
                const datos = await respuestaArchivo.json();
                const nombreContexto = ruta.split('/').pop().replace('.json', '');
                diccionario[nombreContexto] = datos;
                historialRespuestas[nombreContexto] = [];
                console.log(`Cargado: ${nombreContexto}`);
            });

        await Promise.all(promesas);
        console.log("Intenciones cargadas:", Object.keys(diccionario));
    } catch (error) {
        console.error("Error cargando las intenciones dinámicas:", error);
        mostrarMensaje('bot', 'Lo siento, hubo un error al cargar la información. Por favor, inténtalo de nuevo más tarde.');
    }
}






function limpiarTexto(texto) {
    texto = texto.toLowerCase();
    return texto.normalize('NFD')
    .replace(/[\u0300-\u036f]/g, '')
        .replace(/[¿?.;,_+*/\|!¡]/g, '')
    .trim();
}





function encontrarPalabrasClave(texto) {
    texto = limpiarTexto(texto);
    const palabrasEncontradas = [];

    for (let categoria in diccionario) {
        const palabrasClave = diccionario[categoria].palabras;
        palabrasClave.forEach(palabra => {
            if (texto.includes(palabra)) {
                palabrasEncontradas.push(categoria);
            }
        });
    }

    // Asegurarnos de devolver las coincidencias de "saludos" como prioridad si existen
    if (palabrasEncontradas.includes('saludos')) {
        return ['saludos'];
    }

    return [...new Set(palabrasEncontradas)]; // Eliminar duplicados
}





function obtenerRespuestaUnica(categoria) {
    const respuestasCategoria = diccionario[categoria].respuestas;


    if (categoria === 'conocenos' || categoria === 'empresa') {
        return "![Logo de la Empresa](https://placehold.co/250x60/EEE/555?text=Logo%20XYZ&font=Montserrat)\n\n### Empresa XYZ\n\n**Misión**: Brindar soluciones tecnológicas innovadoras que impulsen el crecimiento y eficiencia de nuestros clientes.\n\n**Visión**: Ser el líder en la transformación digital para pequeñas y medianas empresas.\n\n### [Visita nuestro sitio web](https://ejemplo.com) para más detalles.";
    }

    if (categoria === 'contacto') {
        return "Si necesitas ayuda, puedes enviarnos un correo a [soporte@ejemplo.com](mailto:soporte@ejemplo.com) o llamarnos al +1 (123) 456-7890.\n\nTambién estamos disponibles en WhatsApp para resolver cualquier consulta. \n\n### Haz clic [aquí para contactarnos por Whatsapp](https://wa.me/1234567890).";
    }

    const respuestasDisponibles = respuestasCategoria.filter(r => !historialRespuestas.includes(r));

    let respuesta;
    if (respuestasDisponibles.length > 0) {
        respuesta = respuestasDisponibles[Math.floor(Math.random() * respuestasDisponibles.length)];
    } else {
        respuesta = respuestasCategoria[Math.floor(Math.random() * respuestasCategoria.length)];
    }

    historialRespuestas.push(respuesta);
    return respuesta;
}





function enviarMensaje() {
    const mensaje = entradaMensaje.value;
    if (!mensaje) return;

    mostrarMensaje('usuario', mensaje);

    const palabrasClave = encontrarPalabrasClave(mensaje);

    const respuestasGeneradas = new Set();

    if (palabrasClave.length > 0) {
        palabrasClave.forEach(categoria => {
            const respuesta = obtenerRespuestaUnica(categoria);

            if (!respuestasGeneradas.has(respuesta)) {
                respuestasGeneradas.add(respuesta);
                mostrarMensaje('bot', respuesta);
            }
        });
    } else {
        mostrarMensaje('bot', '**Lo siento, no comprendo completamente tu mensaje.**\n\n¿Podrías probar con otros términos?');
    }

    entradaMensaje.value = '';
}





function mostrarMensaje(tipo, texto) {
    const mensajeDiv = document.createElement('div');
    mensajeDiv.classList.add(tipo);

        mensajeDiv.innerHTML = marked.parse(texto); // Procesamos siempre con marked.parse()

        if (tipo === 'bot') {
            mensajeDiv.classList.add('respuesta-bot');
        }

        mensajesContainer.appendChild(mensajeDiv);
        mensajesContainer.scrollTop = mensajesContainer.scrollHeight;
    }

    entradaMensaje.addEventListener('keypress', (e) => {
        if (e.key === 'Enter') {
            enviarMensaje();
        }
    });





// Agregar el evento al botón "Enviar" para garantizar que funcione
document.querySelector('button').addEventListener('click', enviarMensaje);



    window.onload = async () => {
        entradaMensaje.focus();

    // Mostrar mensaje de carga
        mostrarMensaje('bot', '⏳ Cargando información...');

    // Cargar intenciones en segundo plano
        await cargarIntencionesDinamicamente();

    // Actualizar el mensaje de bienvenida una vez que todo esté listo
    mensajesContainer.innerHTML = ''; // Limpiar mensajes previos
    mostrarMensaje('bot', '### 🤓 Soy tu asistente virtual pseudo-inteligente \n\nEstoy aquí para ayudarte y brindar información a partir de palabras clave.\n\n#### Comandos de Ejemplo:\n- `hola` hablame de la `empresa` y sus `servicios`.\n- `Cuéntame` la `historia` de la `compañía`\n- Quien eres\n- háblame de ti...');
};




})();
